import React, {useState} from 'react';
import { arc, interpolateRgb, layout, scaleOrdinal } from 'd3';
import { Slice } from './Slice';
import { Check } from './Check';
import { ColorLegend } from './ColorLegend';
import { PlotMenu } from './PlotMenu';

//const data = [1, 2, 3, 4];

const continents = [
   {name: 'Oblast 1', size: 30.4, pop: 45, Total: 45, Covid: 20, Other: 50},
   {name: 'Oblast 2', size: 10.2, pop: 15, Total: 15, Covid: 20, Other: 15},
   {name: 'Oblast 3', size: 8.6, pop: 15, Total: 15, Covid: 20, Other: 6},
   {name: 'Oblast 4', size: 10.2, pop: 10, Total: 10, Covid: 20, Other: 22},
   {name: 'Oblast 5', size: 8.6, pop: 15, Total: 15, Covid: 20, Other: 7}
];

const themes = [
  {type: 'sezonska davanja', proportion: '5-10 %'},
  {type: 'sport', proportion: '1-3 %'},
  {type: 'kultura', proportion: '1-3 %'},
  {type: 'umetnost', proportion: '1-3 %'},
  {type: 'zastita zivotne sredine', proportion: '1-3 %'},
  {type: 'javna infrastrukutura', proportion: '0-1 %'},
  {type: 'briga o zivotinjama', proportion: '0-1 %'},
  {type: 'urgentna pomoc', proportion: '0-1 %'},
  {type: 'nauka', proportion: '0-1 %'},
  {type: 'istorijsko nasledje', proportion: '0-1 %'},
  {type: 'nezavisni mediji', proportion: '0-1 %'},
  {type: 'socijalno preduzetnistvo', proportion: '0-1 %'},
  {type: 'ekonosmki razvoj', proportion: '0-1 %'},
  {type: 'ostalo', proportion: '0-1 %'},
  {type: 'religijske aktivnosti', proportion: '0-1 %'}
];
const themesGrouped = d3.groups(themes, d => d.proportion);
console.log(themesGrouped[2])

const height = 500;
const width = 960;

const yOffset = 60;
const innerRadius = 180;
const outerRadius = height / 2 - yOffset;

export const SimplePieChart = () => {
  
  const data = continents;
  
  const initialPlotAttribute = 'pop';
  const [plotAttribute, setPlotAttribute] = useState(initialPlotAttribute);
  const plotVariable = d => d[plotAttribute];
  
  //const plotVariable = d => d.Total;
  const textVariable = d => d.name;
  const plotData = data.map(d => plotVariable(d))
  const textData = data.map(d => textVariable(d))
  const circleRadius = 10;
  
  
  const colorValue = (d) => d.name;
  
  
  let pieGnerator = d3.pie().sort(null)
  let pie = pieGnerator(plotData);
  
  const colorScale = scaleOrdinal()
    .domain(data.map(colorValue))
  	.range(data.map(plotVariable));
  
  return (
    <svg height={height} width={width}>
      <g
        transform={`translate(${width * 7 / 10},${height / 2 - yOffset})`}
      >
        <Slice
          pie={pie}
          outerRadius={outerRadius}
          innerRadius={innerRadius}
        />
      </g>      
      <g transform={`translate(${100},${height / 2 - 155})`}>
        	<ColorLegend 
            colorScale={colorScale} 
            tickSpacing={50} 
  					tickSize={circleRadius} 
  					tickTextOffset={10}
          />
      </g>
      <g transform={`translate(${width/ 2},${height - 50})`}>
      	<PlotMenu 
        	updatePlotValue={setPlotAttribute}  
        />
      </g>
      {/* <Check/> */}
    </svg>
  );
};
